@@ -10,11 +10,11 @@
   structure(env, class = "series_obj")
 }
 
-series_obj = function(code) {
-  ser = lapply(seq_along(code), function(ix) .series_obj(code[ix]))
-  info = lapply(ser, series_info)
+series_obj = function(code, load_info = TRUE) {
+  ser <- lapply(seq_along(code), function(ix) .series_obj(code[ix]))
+  info <- if (load_info) lapply(ser, series_info) else rep(NA, length(ser))
   mapply(function(series, info) {
-    series$info = info
+    series$info <- if (!is(info, "list")) NULL else info
     series
   }, ser, info, SIMPLIFY = FALSE, USE.NAMES = FALSE)
 }
\ No newline at end of file
